@@ -1,4 +1,4 @@
-/* $Xorg: fserve.c,v 1.4 2001/02/09 02:04:02 xorgcvs Exp $ */
+/* $XFree86: xc/lib/font/fc/fserve.c,v 3.29 2007/04/09 15:37:13 tsi Exp $ */
 /*
 
 Copyright 1990, 1998  The Open Group
@@ -24,7 +24,6 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/lib/font/fc/fserve.c,v 3.26 2003/11/22 02:12:37 dawes Exp $ */
 
 /*
  * Copyright 1990 Network Computing Devices
@@ -57,12 +56,12 @@ in this Software without prior written authorization from The Open Group.
 #endif
 #include	"X11/Xtrans.h"
 #include	"X11/Xpoll.h"
-#include	"FS.h"
-#include	"FSproto.h"
+#include	<X11/fonts/FS.h>
+#include	<X11/fonts/FSproto.h>
 #include	<X11/X.h>
 #include	<X11/Xos.h>
 #include	"fontmisc.h"
-#include	"fontstruct.h"
+#include	<X11/fonts/fontstruct.h>
 #include	"fservestr.h"
 #include	"fontutil.h"
 #include	<errno.h>
@@ -2214,7 +2213,7 @@ _fs_load_glyphs(pointer client, FontPtr pfont, Bool range_flag,
 	xfree(ranges);
 
 	/* Now try to reopen the font. */
-	return fs_send_open_font(client, (FontPathElementPtr)0,
+	return fs_send_open_font(client, pfont->fpe,
 				 (Mask)FontReopen, (char *)0, 0,
 				 (fsBitmapFormat)0, (fsBitmapFormatMask)0,
 				 (XID)0, &pfont);
@@ -2738,6 +2737,7 @@ _fs_get_conn_setup (FSFpePtr conn, int *error, int *setup_len)
 	*error = ret;
 	return 0;
     }
+    *error = 0;
     *setup_len = len;
     return (fsConnSetup *) data;
 }
