@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/Xprint/Init.c,v 1.17 2006/02/19 15:51:17 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/Xprint/Init.c,v 1.20 2008/01/01 02:02:34 tsi Exp $ */
 /*
 (c) Copyright 1996 Hewlett-Packard Company
 (c) Copyright 1996 International Business Machines Corp.
@@ -95,12 +95,12 @@ static void GenericScreenInit(
     int index,
     ScreenPtr pScreen,
     int argc,
-    char **argv);
+    const char **argv);
 static Bool InitPrintDrivers(
     int index,
     ScreenPtr pScreen,
-    int argc,
-    char **argv);
+    const int argc,
+    const char **argv);
 
 /*
  * The following two defines are used to build the name "X*printers", where
@@ -324,9 +324,9 @@ typedef struct _driverMapping {
     int screenNum;
 } DriverMapEntry, *DriverMapPtr;
 
-static char *configFileName = (char *)NULL;
+static const char *configFileName = (char *)NULL;
 static Bool freeDefaultFontPath = FALSE;
-static char *origFontPath = (char *)NULL;
+static const char *origFontPath = (char *)NULL;
 
 /*
  * XprintOptions checks argv[i] to see if it is our command line
@@ -336,7 +336,7 @@ static char *origFontPath = (char *)NULL;
 int
 XprintOptions(
     int argc,
-    char **argv,
+    const char **argv,
     int i)
 {
     if(strcmp(argv[i], "-XpFile") == 0)
@@ -716,53 +716,66 @@ BuildPrinterDb(void)
 	char line[256];
 	FILE *fp = fopen(configFileName, "r");
 
-	while(fgets(line, 256, fp) != (char *)NULL)
+	if(!fp)
 	{
-	    char *tok, *ptr;
-	    if((tok = strtok(line, " \t\012")) != (char *)NULL)
+	    ErrorF("Xp Extension: Can't open file %s\n", configFileName);
+	    configFileName = (char *)NULL;
+	}
+	else
+	{
+	    while(fgets(line, 256, fp) != (char *)NULL)
 	    {
-		if(tok[0] == (char)'#') continue;
-		if(strcmp(tok, "Printer") == 0)
+		char *tok, *ptr;
+		if((tok = strtok(line, " \t\012")) != (char *)NULL)
 		{
-		    while((tok = strtok((char *)NULL, " \t")) != (char *)NULL)
+		    if(tok[0] == (char)'#')
+			continue;
+		    if(strcmp(tok, "Printer") == 0)
 		    {
-		        if ((ptr = MbStrchr(tok, '\012')) != 0)
-		            *ptr = (char)'\0';
-			AddPrinterDbName(tok);
+			while((tok = strtok((char *)NULL, " \t")) !=
+			      (char *)NULL)
+			{
+			    if ((ptr = MbStrchr(tok, '\012')) != 0)
+				*ptr = (char)'\0';
+			    AddPrinterDbName(tok);
+			}
 		    }
-		}
-		else if(strcmp(tok, "Map") == 0)
-		{
-		    char *name, *qualifier;
+		    else if(strcmp(tok, "Map") == 0)
+		    {
+			char *name, *qualifier;
 
-		    if((tok = strtok((char *)NULL, " \t\012")) == (char *)NULL)
-			continue;
-		    name = strdup(tok);
-		    if((tok = strtok((char *)NULL, " \t\012")) == (char *)NULL)
+			if((tok = strtok((char *)NULL, " \t\012")) ==
+			   (char *)NULL)
+			    continue;
+			name = strdup(tok);
+			if((tok = strtok((char *)NULL, " \t\012")) ==
+			   (char *)NULL)
+			{
+			    xfree(name);
+			    continue;
+			}
+			qualifier = strdup(tok);
+			AddNameMap(name, qualifier);
+		    }
+		    else if(strcmp(tok, "Augment_Printer_List") == 0)
 		    {
-			xfree(name);
-			continue;
+			if((tok = strtok((char *)NULL, " \t\012")) ==
+			   (char *)NULL)
+			    continue;
+
+			if(strcmp(tok, "%default%") == 0)
+			    continue;
+			defaultAugment = FALSE;
+			if(strcmp(tok, "%none%") == 0)
+			    continue;
+			AugmentPrinterDb(tok);
 		    }
-		    qualifier = strdup(tok);
-		    AddNameMap(name, qualifier);
-		}
-		else if(strcmp(tok, "Augment_Printer_List") == 0)
-		{
-		    if((tok = strtok((char *)NULL, " \t\012")) == (char *)NULL)
-			continue;
-
-		    if(strcmp(tok, "%default%") == 0)
-			continue;
-		    defaultAugment = FALSE;
-		    if(strcmp(tok, "%none%") == 0)
-			continue;
-		    AugmentPrinterDb(tok);
+		    else
+			break; /* XXX Generate an error? */
 		}
-		else
-		    break; /* XXX Generate an error? */
 	    }
+	    fclose(fp);
 	}
-	fclose(fp);
     }
 
     if(defaultAugment == TRUE)
@@ -1227,7 +1240,7 @@ void
 PrinterInitOutput(
      ScreenInfo *pScreenInfo,
      int argc,
-     char **argv)
+     const char **argv)
 {
     PrinterDbPtr pDb, pDbEntry;
     int driverCount, i;
@@ -1399,8 +1412,8 @@ static Bool
 InitPrintDrivers(
     int index,
     ScreenPtr pScreen,
-    int argc,
-    char **argv)
+    const int argc,
+    const char **argv)
 {
     PrinterDbPtr pDb, pDb2;
 
@@ -1456,7 +1469,7 @@ GenericScreenInit(
      int index,
      ScreenPtr pScreen,
      int argc,
-     char **argv)
+     const char **argv)
 {
     float fWidth, fHeight, maxWidth, maxHeight;
     unsigned short width, height;
