@@ -1,5 +1,5 @@
 /*
- * $XFree86: xc/programs/Xserver/hw/tinyx/tinyx.c,v 1.1 2004/06/02 22:43:00 dawes Exp $ 
+ * $XFree86: xc/programs/Xserver/hw/tinyx/tinyx.c,v 1.4 2006/11/02 21:55:25 tsi Exp $ 
  *
  * Copyright  1999 Keith Packard
  *
@@ -22,7 +22,7 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 /*
- * Copyright (c) 2004 by The XFree86 Project, Inc.
+ * Copyright (c) 2004-2006 by The XFree86 Project, Inc.
  * All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -82,10 +82,6 @@
 #include "txxv.h"
 #endif
 
-#ifdef DPMSExtension
-#include "dpmsproc.h"
-#endif
-
 CARD8	kdBpp[] = { 1, 4, 8, 16, 24, 32 };
 
 #define NUM_KD_BPP (sizeof (kdBpp) / sizeof (kdBpp[0]))
@@ -102,6 +98,7 @@ int		    kdSubpixelOrder;
 int		    kdVirtualTerminal = -1;
 Bool		    kdSwitchPending;
 DDXPointRec	    kdOrigin;
+Bool		    kdNoSerialMouse = FALSE;
 
 /*
  * Carry arguments from InitOutput through driver initialization
@@ -385,6 +382,7 @@ KdUseMsg()
   ErrorF("-videoTest	Start the server, pause momentarily and exit\n");
   ErrorF("-origin X,Y	Locates the next screen in the the virtual screen (Xinerama)\n");
   ErrorF("-mouse path[,n]	Filename of mouse device, n is number of buttons\n");
+  ErrorF("-noserialmouse	Don't probe for a serial mouse\n");
   ErrorF("vtxx		Use virtual terminal xx instead of the next available\n");
   ErrorF("\n");
 }
@@ -398,8 +396,8 @@ ddxGiveUp ()
 Bool	kdDumbDriver;
 Bool	kdSoftCursor;
 
-static char *
-KdParseFindNext (char *cur, char *delim, char *save, char *last)
+static const char *
+KdParseFindNext (const char *cur, const char *delim, char *save, char *last)
 {
     while (*cur && !strchr (delim, *cur))
     {
@@ -436,7 +434,7 @@ KdSubRotation (Rotation a, Rotation b)
 
 void
 KdParseScreen (KdScreenInfo *screen,
-	       char	    *arg)
+	       const char    *arg)
 {
     char    delim;
     char    save[1024];
@@ -590,7 +588,7 @@ KdSaveString (char *str)
  */
 
 void
-KdParseMouse (char *arg)
+KdParseMouse (const char *arg)
 {
     char	save[1024];
     char	delim;
@@ -666,7 +664,7 @@ KdParseMouse (char *arg)
 }
 
 static void
-KdParseRgba (char *rgba)
+KdParseRgba (const char *rgba)
 {
     if (!strcmp (rgba, "rgb"))
 	kdSubpixelOrder = SubPixelHorizontalRGB;
@@ -683,7 +681,7 @@ KdParseRgba (char *rgba)
 }
 
 int
-KdProcessArgument (int argc, char **argv, int i)
+KdProcessArgument (int argc, const char **argv, int i)
 {
     KdCardInfo	    *card;
     KdScreenInfo    *screen;
@@ -750,7 +748,7 @@ KdProcessArgument (int argc, char **argv, int i)
     {
 	if ((i+1) < argc)
 	{
-	    char    *x = argv[i+1];
+	    const char    *x = argv[i+1];
 	    char    *y = strchr (x, ',');
 	    if (x)
 		kdOrigin.x = atoi (x);
@@ -773,6 +771,11 @@ KdProcessArgument (int argc, char **argv, int i)
 	    UseMsg ();
 	return 2;
     }
+    if (!strcmp (argv[i], "-noserialmouse"))
+    {
+	kdNoSerialMouse = TRUE;
+	return 1;
+    }
     if (!strcmp (argv[i], "-rgba"))
     {
 	if ((i+1) < argc)
@@ -1001,7 +1004,7 @@ KdSetSubpixelOrder (ScreenPtr pScreen, Rotation randr)
 static KdScreenInfo *kdCurrentScreen;
 
 Bool
-KdScreenInit(int index, ScreenPtr pScreen, int argc, char **argv)
+KdScreenInit(int index, ScreenPtr pScreen, int argc, const char **argv)
 {
     KdScreenInfo	*screen = kdCurrentScreen;
     KdCardInfo		*card = screen->card;
@@ -1018,9 +1021,6 @@ KdScreenInit(int index, ScreenPtr pScreen, int argc, char **argv)
     for (fb = 0; fb < KD_MAX_FB && screen->fb[fb].depth; fb++)
 	pScreenPriv->bytesPerPixel[fb] = screen->fb[fb].bitsPerPixel >> 3;
     pScreenPriv->dpmsState = KD_DPMS_NORMAL;
-#ifdef PANORAMIX
-    dixScreenOrigins[pScreen->myNum] = screen->origin;
-#endif
 
     if (!monitorResolution)
 	monitorResolution = 75;
@@ -1199,7 +1199,7 @@ void
 KdInitScreen (ScreenInfo    *pScreenInfo,
 	      KdScreenInfo  *screen,
 	      int	    argc,
-	      char	    **argv)
+	      const char	    **argv)
 {
     KdCardInfo	*card = screen->card;
     
@@ -1281,7 +1281,7 @@ static void
 KdAddScreen (ScreenInfo	    *pScreenInfo,
 	     KdScreenInfo   *screen,
 	     int	    argc,
-	     char	    **argv)
+	     const char	    **argv)
 {
     int	    i;
     /*
@@ -1335,7 +1335,7 @@ KdDepthToFb (ScreenPtr	pScreen, int depth)
 void
 KdInitOutput (ScreenInfo    *pScreenInfo,
 	      int	    argc,
-	      char	    **argv)
+	      const char	    **argv)
 {
     KdCardInfo	    *card;
     KdScreenInfo    *screen;
@@ -1379,48 +1379,3 @@ void
 OsVendorFatalError()
 {
 }
-
-#ifdef XTESTEXT1
-void
-XTestGenerateEvent(dev_type, keycode, keystate, mousex, mousey)
-	int	dev_type;
-	int	keycode;
-	int	keystate;
-	int	mousex;
-	int	mousey;
-{
-}
-
-void
-XTestGetPointerPos(fmousex, fmousey)
-	short *fmousex, *fmousey;
-{
-}
-
-void
-XTestJumpPointer(jx, jy, dev_type)
-	int	jx;
-	int	jy;
-	int	dev_type;
-{
-}
-#endif
-
-#ifdef DPMSExtension
-void
-DPMSSet(int level)
-{
-}
-
-int
-DPMSGet (int *level)
-{
-    return -1;
-}
-
-Bool
-DPMSSupported (void)
-{
-    return FALSE;
-}
-#endif
