@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/loader/loader.c,v 1.80 2006/04/08 17:53:40 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/loader/loader.c,v 1.83 2006/08/18 14:36:05 tsi Exp $ */
 
 /*
  * Copyright 1995-1998 by Metro Link, Inc.
@@ -722,6 +722,11 @@ _LoaderFileToMem(int fd, unsigned long offset, int size, char *label)
 	new_size += pagesize;
     ret = (unsigned long)mmap(0, new_size, MMAP_PROT, MMAP_FLAGS, fd,
 			      new_off);
+#  if LOADERDEBUG
+    LoaderDebugMsg(LOADER_DEBUG_MEM,
+		   "mmap: new_off %lx, new_off_bias %lx, new_size %lu, ret %lx\n",
+		   new_off, new_off_bias, new_size, ret);
+#  endif
     if (ret == -1)
 	FatalError("mmap() failed: %s\n", strerror(errno));
     return (void *)(ret + new_off_bias);
@@ -1840,14 +1845,15 @@ LoaderOpen(const char *module, const char *cname, int handle,
 	    *errmaj = LDR_UNKTYPE;
 	if (errmin)
 	    *errmin = LDR_UNKTYPE;
+	close(fd);
 	return -1;
-    } else {
-#if LOADERDEBUG
-	LoaderDebugMsg(LOADER_DEBUG_FILES, "Module %s is type %d (%s)\n",
-		       module, modtype, loaderNames[modtype]);
-#endif
     }
 
+#if LOADERDEBUG
+    LoaderDebugMsg(LOADER_DEBUG_FILES, "Module %s is type %d (%s)\n",
+		   module, modtype, loaderNames[modtype]);
+#endif
+
     tmp = _LoaderListPush();
     tmp->name = xf86loadermalloc(strlen(module) + 1);
     strcpy(tmp->name, module);
@@ -1865,6 +1871,7 @@ LoaderOpen(const char *module, const char *cname, int handle,
 	    *errmaj = LDR_NOLOAD;
 	if (errmin)
 	    *errmin = LDR_NOLOAD;
+	close(fd);
 	return -1;
     }
 
@@ -2100,11 +2107,14 @@ LoaderClearOptions(unsigned long opts)
 }
 
 unsigned long LoaderDebugLevel = 0;
+static unsigned long LoaderSaveDebugLevel = 0;
+static const char **LoaderDebugList = NULL;
+static int numLoaderDebugList = 0;
 
 void
 LoaderSetDebug(unsigned long level)
 {
-    LoaderDebugLevel = level;
+    LoaderSaveDebugLevel = LoaderDebugLevel = level;
 }
 
 void
@@ -2118,6 +2128,47 @@ LoaderDebugMsg(unsigned long debug, const char *f, ...)
     va_end(args);
 }
 
+static int
+LoaderDebugModuleInList(const char *module)
+{
+    int i;
+
+    /* If no list, debugging applies to all modules. */
+    if (!LoaderDebugList || !numLoaderDebugList)
+	return 1;
+
+    for (i = 0; i < numLoaderDebugList; i++)
+	if (LoaderDebugList[i] && strcmp(module, LoaderDebugList[i]) == 0)
+	    return 1;
+    return 0;
+}
+
+void
+LoaderDebugAddModule(const char *module)
+{
+    const char **l;
+
+    if (LoaderDebugList && LoaderDebugModuleInList(module))
+	return;
+
+    numLoaderDebugList++;
+    l = xrealloc(LoaderDebugList,
+		 numLoaderDebugList * sizeof(*LoaderDebugList));
+    if (l) {
+	l[numLoaderDebugList - 1] = module;
+	LoaderDebugList = l;
+    }
+}
+
+void
+LoaderDebugForModule(const char *module)
+{
+    if (LoaderDebugModuleInList(module))
+	LoaderDebugLevel = LoaderSaveDebugLevel;
+    else
+	LoaderDebugLevel = 0;
+}
+
 /*
  * The return value is the user-recognisable file name, and *path is set
  * to the name of a full path that can be used to open the executable file
