@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/parser/scan.c,v 1.30 2003/11/03 05:11:52 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/parser/scan.c,v 1.34 2006/08/09 20:53:16 dawes Exp $ */
 /* 
  * 
  * Copyright (c) 1997  Metro Link Incorporated
@@ -27,30 +27,50 @@
  * 
  */
 /*
- * Copyright (c) 1997-2003 by The XFree86 Project, Inc.
+ * Copyright (c) 1997-2006 by The XFree86 Project, Inc.
+ * All rights reserved.
  *
- * Permission is hereby granted, free of charge, to any person obtaining a
- * copy of this software and associated documentation files (the "Software"),
- * to deal in the Software without restriction, including without limitation
- * the rights to use, copy, modify, merge, publish, distribute, sublicense,
- * and/or sell copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following conditions:
+ * Permission is hereby granted, free of charge, to any person obtaining
+ * a copy of this software and associated documentation files (the
+ * "Software"), to deal in the Software without restriction, including
+ * without limitation the rights to use, copy, modify, merge, publish,
+ * distribute, sublicense, and/or sell copies of the Software, and to
+ * permit persons to whom the Software is furnished to do so, subject
+ * to the following conditions:
  *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
+ *   1.  Redistributions of source code must retain the above copyright
+ *       notice, this list of conditions, and the following disclaimer.
  *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
- * THE COPYRIGHT HOLDER(S) OR AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR
- * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
- * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
- * OTHER DEALINGS IN THE SOFTWARE.
+ *   2.  Redistributions in binary form must reproduce the above copyright
+ *       notice, this list of conditions and the following disclaimer
+ *       in the documentation and/or other materials provided with the
+ *       distribution, and in the same place and form as other copyright,
+ *       license and disclaimer information.
  *
- * Except as contained in this notice, the name of the copyright holder(s)
- * and author(s) shall not be used in advertising or otherwise to promote
- * the sale, use or other dealings in this Software without prior written
- * authorization from the copyright holder(s) and author(s).
+ *   3.  The end-user documentation included with the redistribution,
+ *       if any, must include the following acknowledgment: "This product
+ *       includes software developed by The XFree86 Project, Inc
+ *       (http://www.xfree86.org/) and its contributors", in the same
+ *       place and form as other third-party acknowledgments.  Alternately,
+ *       this acknowledgment may appear in the software itself, in the
+ *       same form and location as other such third-party acknowledgments.
+ *
+ *   4.  Except as contained in this notice, the name of The XFree86
+ *       Project, Inc shall not be used in advertising or otherwise to
+ *       promote the sale, use or other dealings in this Software without
+ *       prior written authorization from The XFree86 Project, Inc.
+ *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
+ * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE XFREE86 PROJECT, INC OR ITS CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+ * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
+ * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
+ * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
+ * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
+ * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
+ * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -89,7 +109,7 @@
 
 #define CONFIG_BUF_LEN     1024
 
-static int StringToToken (char *, xf86ConfigSymTabRec *);
+static int StringToToken (const char *, xf86ConfigSymTabRec *);
 
 static FILE *configFile = NULL;
 static const char **builtinConfig = NULL;
@@ -294,8 +314,8 @@ again:
 			}
 			while ((c != '\"') && (c != '\n') && (c != '\r') && (c != '\0'));
 			configRBuf[i] = '\0';
-			val.str = xf86confmalloc (strlen (configRBuf) + 1);
-			strcpy (val.str, configRBuf);	/* private copy ! */
+			/* No private copy! */
+			val.str = configRBuf;
 			return (STRING);
 		}
 
@@ -473,25 +493,28 @@ xf86pathIsSafe(const char *path)
 #endif
 #endif
 
-#define BAIL_OUT		do {									\
-							xf86conffree(result);				\
-							return NULL;						\
-						} while (0)
+#define BAIL_OUT		\
+    do {			\
+	xf86conffree(result);	\
+	return NULL;		\
+    } while (0)
 
-#define CHECK_LENGTH	do {									\
-							if (l > PATH_MAX) {					\
-								BAIL_OUT;						\
-							}									\
-						} while (0)
+#define CHECK_LENGTH		\
+    do {			\
+	if (l > PATH_MAX) {	\
+	    BAIL_OUT;		\
+	}			\
+    } while (0)
 
-#define APPEND_STR(s)	do {									\
-							if (strlen(s) + l > PATH_MAX) {		\
-								BAIL_OUT;						\
-							} else {							\
-								strcpy(result + l, s);			\
-								l += strlen(s);					\
-							}									\
-						} while (0)
+#define APPEND_STR(s)			\
+    do {				\
+	if (strlen(s) + l > PATH_MAX) {	\
+	    BAIL_OUT;			\
+	} else {			\
+	    strcpy(result + l, s);	\
+	    l += strlen(s);		\
+	}				\
+    } while (0)
 
 static char *
 DoSubstitution(const char *template, const char *cmdline, const char *projroot,
@@ -750,16 +773,21 @@ xf86closeConfigFile (void)
 void
 xf86setBuiltinConfig(const char *config[])
 {
+	/* Reset counters, etc. */
+	pushToken = LOCK_TOKEN;
+	configPos = 0;
+	configLineNo = 0;
+	configFile = NULL;
+
 	builtinConfig = config;
 	configPath = xf86configStrdup("<builtin configuration>");
 	configBuf = xf86confmalloc (CONFIG_BUF_LEN);
 	configRBuf = xf86confmalloc (CONFIG_BUF_LEN);
 	configBuf[0] = '\0';		/* sanity ... */
-
 }
 
 void
-xf86parseError (char *format,...)
+xf86parseError (const char *format,...)
 {
 	va_list ap;
 
@@ -773,7 +801,7 @@ xf86parseError (char *format,...)
 }
 
 void
-xf86parseWarning (char *format,...)
+xf86parseWarning (const char *format,...)
 {
 	va_list ap;
 
@@ -787,7 +815,7 @@ xf86parseWarning (char *format,...)
 }
 
 void
-xf86validationError (char *format,...)
+xf86validationError (const char *format,...)
 {
 	va_list ap;
 
@@ -800,12 +828,11 @@ xf86validationError (char *format,...)
 }
 
 void
-xf86setSection (char *section)
+xf86setSection (const char *section)
 {
 	if (configSection)
 		xf86conffree(configSection);
-	configSection = xf86confmalloc(strlen (section) + 1);
-	strcpy (configSection, section);
+	configSection = xf86configStrdup(section);
 }
 
 /* 
@@ -819,7 +846,7 @@ xf86getStringToken (xf86ConfigSymTabRec * tab)
 }
 
 static int
-StringToToken (char *str, xf86ConfigSymTabRec * tab)
+StringToToken (const char *str, xf86ConfigSymTabRec * tab)
 {
 	int i;
 
@@ -871,9 +898,10 @@ xf86nameCompare (const char *s1, const char *s2)
 }
 
 char *
-xf86addComment(char *cur, char *add)
+xf86addComment(char *cur, const char *add)
 {
 	char *str;
+	const char *s;
 	int len, curlen, iscomment, hasnewline = 0, endnewline;
 
 	if (add == NULL || add[0] == '\0')
@@ -888,14 +916,14 @@ xf86addComment(char *cur, char *add)
 	else
 		curlen = 0;
 
-	str = add;
+	s = add;
 	iscomment = 0;
-	while (*str) {
-	    if (*str != ' ' && *str != '\t')
+	while (*s) {
+	    if (*s != ' ' && *s != '\t')
 		break;
-	    ++str;
+	    ++s;
 	}
-	iscomment = (*str == '#');
+	iscomment = (*s == '#');
 
 	len = strlen(add);
 	endnewline = add[len - 1] == '\n';
@@ -916,3 +944,61 @@ xf86addComment(char *cur, char *add)
 
 	return (cur);
 }
+
+char *
+xf86configStrdup (const char *s)
+{
+	char *tmp;
+	if (!s) return NULL;
+	tmp = xf86confmalloc (sizeof (char) * (strlen (s) + 1));
+	if (tmp)
+		strcpy (tmp, s);
+	return (tmp);
+}
+
+int
+xf86configAsprintf (char **ret, const char *format, ...)
+{
+	char *s;
+	va_list args;
+	int status;
+
+	if (!ret || !format)
+		return -1;
+
+#ifdef HAS_ASPRINTF
+	va_start(args, format);
+	status = vasprintf(&s, format, args);
+	va_end(args);
+	if (status != -1 && s) {
+		*ret = xf86configStrdup(s);
+		free(s);
+		if (!*ret)
+			status = -1;
+	} else
+		*ret = NULL;
+	return status;
+#else
+#define TMP_SIZE 4000
+	s = xf86confcalloc(1, TMP_SIZE);
+	if (!s) {
+		*ret = NULL;
+		return -1;
+	}
+	va_start(args, format);
+	status = vsnprintf(s, TMP_SIZE, format, args);
+	va_end(args);
+	if (status > TMP_SIZE - 1)
+		status = TMP_SIZE - 1;
+	if (status < TMP_SIZE - 1) {
+		*ret = xf86confrealloc(s, status + 1);
+		if (!*ret) {
+			xf86conffree(s);
+			status = -1;
+		}
+	} else
+		*ret = s;
+	return status;
+#endif
+}
+
